Module http

Module http 

Functions

http_get
Send a GET request and return the response body as a string.
http_post
Send a POST request with a string body and return the response body.
http_post_json
Send a POST request with a JSON body and return the response body.