Module http
agent_
line
0.1.2
Module http
Module Items
Functions
In agent_
line::
tools
agent_line
::
tools
Module
http
Functions

http_
get
Send a GET request and return the response body as a string.
http_
post
Send a POST request with a string body and return the response body.
http_
post_
json
Send a POST request with a JSON body and return the response body.