Functions
- extract_
json - Extract the first JSON object or array from text that may contain prose.
- parse_
lines - Split LLM output into lines, stripping numbering, bullets, and whitespace.
- strip_
code_ fences - Remove markdown code fences from LLM output.